/*!
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */.panel-heading #alerts-accordion-toggle:after{color:grey;content:"\f078";float:right;font-family:FontAwesome}.panel-heading #alerts-accordion-toggle.collapsed:after{color:grey;content:"\f054";float:right;font-family:FontAwesome}#errorHeading{background-color:#d6d8d9}.dag-import-error{cursor:pointer;height:14px;line-height:14px;overflow:hidden;position:relative;white-space:pre}.expanded-error{height:100%}.dag-import-error:after{color:#e43921;content:"\f054";float:right;font-family:FontAwesome;position:absolute;right:0;top:0}.dag-import-error.expanded-error:after{content:"\f078"}